//
//  TagFileParser.swift
//  
//
//  Created by Loris Perret on 05/12/2023.
//

import Foundation

class TagFileParser {
    static func parse(_ inputFile: String) -> [TagSection] {
        let inputFileContent = try! String(contentsOfFile: inputFile, encoding: .utf8)
        let stringsByLines = inputFileContent.components(separatedBy: .newlines)
        
        var sections = [TagSection]()
        
        // Parse file
        stringsByLines.forEach {
            // TagSection
            if let section = TagSection.match($0) {
                sections.append(section)
                return
            }
            
            // Definition
            if let definition = TagDefinition.match($0) {
                sections.last?.definitions.append(definition)
                return
            }
            
            // Definition content
            if $0.isEmpty == false {
                // name = Test => ["name ", " Test"]
                let splitLine = $0
                    .removeLeadingTrailingWhitespace()
                    .split(separator: "=")
                
                guard let lastDefinition = sections.last?.definitions.last,
                      let leftElement = splitLine.first else {
                          return
                      }
                
                let rightElement: String = splitLine.dropFirst().joined(separator: "=")
                    
                // "name " => "name"
                let leftHand = String(leftElement).removeTrailingWhitespace()
                // " Test" => "Test"
                let rightHand = String(rightElement).removeLeadingWhitespace()
                
                // Handle comments, tags and translation
                switch leftHand {
                case "comments":
                    lastDefinition.comment = rightHand
                    
                case "tags":
                    lastDefinition.tags = rightHand
                        .split(separator: ",")
                        .map { String($0) }
                    
                case "path":
                    lastDefinition.path = rightHand
                    
                case "name":
                    lastDefinition.name = rightHand
                    
                case "type":
                    lastDefinition.type = rightHand
                    
                default:
                    break
                }
            }
        }
        
        // Keep only valid definition
        var invalidDefinitionNames = [String]()
        sections.forEach { section in
            section.definitions = section.definitions
                .filter {
                    if $0.isValid == false {
                        invalidDefinitionNames.append($0.name)
                        return false
                    }
                    return true
                }
        }
        if invalidDefinitionNames.count > 0 {
            print("warning: [\(Stringium.toolName)] Found \(invalidDefinitionNames.count) definition (\(invalidDefinitionNames.joined(separator: ", "))")
        }
        
        return sections
    }
}
